import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getCsqxtfz() {
    let interfaceName = "城市群协同发展";
    let {basicData, wujiangDistriceData, qinpuDistriceData, jiashanDistriceData, demonstrationAreaIndexTrend} = await getInterfaceByInterfaceName(interfaceName);
    // let basicData;
    // let demonstrationAreaIndexTrend;

    if(!basicData) throw new BizError(`${interfaceName} 缺少参数 basicData`);
    if(!demonstrationAreaIndexTrend) throw new BizError(`${interfaceName} 缺少参数 demonstrationAreaIndexTrend`);

    let {regionalIndex, economic, nonAgriculturalIndustries, resourcesEndowment} = basicData;
    let basicInfo = [
        {区域协同发展指数: regionalIndex},
        {经济协同发展: economic},
        {非农产业协同发展: nonAgriculturalIndustries},
        {资源禀赋协同发展: resourcesEndowment}
    ];

    //长三角示范区一体化协同发展指数趋势
    let demonstrationInfo = {};
    demonstrationAreaIndexTrend.forEach( info => {
        let {month, value} = info;
        demonstrationInfo[month] = value;
    })

    return {basicInfo, demonstrationInfo}
}

export async function getArea(area) {
    let interfaceName = "城市群协同发展";
    let {basicData, wujiangDistriceData, qinpuDistriceData, jiashanDistriceData, demonstrationAreaIndexTrend} = await getInterfaceByInterfaceName(interfaceName);
    // let wujiangDistriceData;
    // let qinpuDistriceData;
    // let jiashanDistriceData;

    if(!wujiangDistriceData) throw new BizError(`${interfaceName} 缺少参数 wujiangDistriceData`);
    if(!qinpuDistriceData) throw new BizError(`${interfaceName} 缺少参数 qinpuDistriceData`);
    if(!jiashanDistriceData) throw new BizError(`${interfaceName} 缺少参数 jiashanDistriceData`);

    let deJurePopulation;
    let ardeJurePopulationea;
    let GDP;
    let totalElectricityConsumption;
    let maximumSocialLload;
    let cumulativeInstallationCapacity;

    if(area == "吴江") {
        deJurePopulation = wujiangDistriceData.deJurePopulation;
        ardeJurePopulationea = wujiangDistriceData.ardeJurePopulationea;
        GDP = wujiangDistriceData.GDP;
        totalElectricityConsumption = wujiangDistriceData.totalElectricityConsumption;
        maximumSocialLload = wujiangDistriceData.maximumSocialLload;
        cumulativeInstallationCapacity = wujiangDistriceData.cumulativeInstallationCapacity;
    } else if(area == "青浦") {
        deJurePopulation = qinpuDistriceData.deJurePopulation;
        ardeJurePopulationea = qinpuDistriceData.ardeJurePopulationea;
        GDP = qinpuDistriceData.GDP;
        totalElectricityConsumption = qinpuDistriceData.totalElectricityConsumption;
        maximumSocialLload = qinpuDistriceData.maximumSocialLload;
        cumulativeInstallationCapacity = qinpuDistriceData.cumulativeInstallationCapacity;
    } else if(area == "嘉善") {
        deJurePopulation = jiashanDistriceData.deJurePopulation;
        ardeJurePopulationea = jiashanDistriceData.ardeJurePopulationea;
        GDP = jiashanDistriceData.GDP;
        totalElectricityConsumption = jiashanDistriceData.totalElectricityConsumption;
        maximumSocialLload = jiashanDistriceData.maximumSocialLload;
        cumulativeInstallationCapacity = jiashanDistriceData.cumulativeInstallationCapacity;
    }

    let dataInfo = [
        {常住人口: deJurePopulation},
        {面积: ardeJurePopulationea},
        {GDP: GDP},
        {全社会用电量: totalElectricityConsumption},
        {全社会最大负荷: maximumSocialLload},
        {累计装接容量: cumulativeInstallationCapacity}
    ];

    return {dataInfo}
}
