import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getZzkzl() {
    let interfaceName = "住宅空置率";
    let {vacantHouseholdData, housingVacancyRateData, IdleUserPowerData, qingPuDistrictHousingVacancyRateTrend, housingVacancyRateInKeyAreas,
        typicalResidentialVacancyRate, vacantHouseholdsInKeyAreas, typicalResidentialVacancyTrends} = await getInterfaceByInterfaceName(interfaceName);
    // let vacantHouseholdData;
    // let housingVacancyRateData;
    // let IdleUserPowerData;
    // let qingPuDistrictHousingVacancyRateTrend;
    // let housingVacancyRateInKeyAreas;
    // let typicalResidentialVacancyRate;
    // let vacantHouseholdsInKeyAreas;
    // let typicalResidentialVacancyTrends;

    if (!vacantHouseholdData) throw new BizError(`${interfaceName} 缺少参数 vacantHouseholdData` );
    if (!housingVacancyRateData) throw new BizError(`${interfaceName} 缺少参数 housingVacancyRateData` );
    if (!IdleUserPowerData) throw new BizError(`${interfaceName} 缺少参数 IdleUserPowerData` );
    if (!qingPuDistrictHousingVacancyRateTrend) throw new BizError(`${interfaceName} 缺少参数 qingPuDistrictHousingVacancyRateTrend` );
    if (!housingVacancyRateInKeyAreas) throw new BizError(`${interfaceName} 缺少参数 housingVacancyRateInKeyAreas` );
    if (!typicalResidentialVacancyRate) throw new BizError(`${interfaceName} 缺少参数 typicalResidentialVacancyRate` );
    if (!vacantHouseholdsInKeyAreas) throw new BizError(`${interfaceName} 缺少参数 vacantHouseholdsInKeyAreas` );
    if (!typicalResidentialVacancyTrends) throw new BizError(`${interfaceName} 缺少参数 typicalResidentialVacancyTrends` );

    //空置户数据
    let {numberOfVacantHouseholds, chainRatio, yoy} = vacantHouseholdData;
    let vacantHouseholdInfo = [
        {空置户数量: numberOfVacantHouseholds},
        {环比: chainRatio},
        {同比: yoy}
    ];

    //青浦区住房空置率趋势
    let qingPuDistrictHousing = {};
    qingPuDistrictHousingVacancyRateTrend.forEach( info => {
        let {month, quantity} = info;
        qingPuDistrictHousing[month] = quantity;
    });

    //重点区域住房空置率
    let housingVacancyInfo;
    let userNumData = {};
    let vacancyRateData = {};
    housingVacancyRateInKeyAreas.forEach( info => {
        let {keyAreaName, userNum, vacancyRate} = info;
        userNumData[keyAreaName] = userNum;
        vacancyRateData[keyAreaName] = vacancyRate;
    })
    housingVacancyInfo = {用户数: userNumData, 空置率: vacancyRateData};
    

    return {vacantHouseholdInfo, qingPuDistrictHousing, housingVacancyInfo};
}

export async function getHousingVacancyRate() {
    let interfaceName = "住宅空置率";
    let zzkzlData = await getInterfaceByInterfaceName(interfaceName);
    // let zzkzlData;

    if (!zzkzlData.housingVacancyRateData) throw new BizError(`${interfaceName} 缺少参数 housingVacancyRateData` );
    
    //住房空置率数据
    let {housingVacancyRate, chainRatio, yoy} = zzkzlData.housingVacancyRateData;
    let housingVacancyRateInfo = [
        {住房空置率: housingVacancyRate},
        {环比: chainRatio},
        {同比: yoy}
    ];

    return {housingVacancyRateInfo};
}

export async function getIdleUserPower() {
    let interfaceName = "住宅空置率";
    // let zzkzlData = await getInterfaceByInterfaceName(interfaceName);
    let zzkzlData;

    if (!zzkzlData.IdleUserPowerData) throw new BizError(`${interfaceName} 缺少参数 IdleUserPowerData` );
    
    //空置用户电量数据
    let {averagePowerConsumptionOfVacantUsers, chainRatio, yoy} = zzkzlData.IdleUserPowerData;
    let IdleUserPowerInfo = [
        {空置用户平均电量: averagePowerConsumptionOfVacantUsers},
        {环比: chainRatio},
        {同比: yoy}
    ];

    return {IdleUserPowerInfo};
}

export async function getResidentialVacancyRate() {
    let interfaceName = "住宅空置率";
    let zzkzlData = await getInterfaceByInterfaceName(interfaceName);
    // let zzkzlData;

    if (!zzkzlData.typicalResidentialVacancyRate) throw new BizError(`${interfaceName} 缺少参数 typicalResidentialVacancyRate` );
    
    //典型小区住房空置率
    let residentialVacancyRate = zzkzlData.typicalResidentialVacancyRate;
    
    let residentialVacancyRateInfo;
    let userNumData = {};
    let vacancyRateData = {};
    residentialVacancyRate.forEach( info => {
        let {keyAreaName, userNum, vacancyRate} = info;
        userNumData[keyAreaName] = userNum;
        vacancyRateData[keyAreaName] = vacancyRate;
    })
    residentialVacancyRateInfo = {用户数: userNumData, 空置率: vacancyRateData};

    return {residentialVacancyRateInfo};
}

export async function getVacantHouseholdsInKeyAreas() {
    let interfaceName = "住宅空置率";
    let zzkzlData = await getInterfaceByInterfaceName(interfaceName);
    // let zzkzlData;

    if (!zzkzlData.vacantHouseholdsInKeyAreas) throw new BizError(`${interfaceName} 缺少参数 vacantHouseholdsInKeyAreas` );

    //重点区域空置户趋势
    let vacantHouseholdsData = zzkzlData.vacantHouseholdsInKeyAreas;
    let vacantHouseholds = {};
    vacantHouseholdsData.forEach( info => {
        let {month, quantity} = info;
        vacantHouseholds[month] = quantity;
    });

    return {vacantHouseholds}
}

export async function getTypicalResidentialVacancyTrends() {
    let interfaceName = "住宅空置率";
    let zzkzlData = await getInterfaceByInterfaceName(interfaceName);
    // let zzkzlData;

    if (!zzkzlData.typicalResidentialVacancyTrends) throw new BizError(`${interfaceName} 缺少参数 typicalResidentialVacancyTrends` );

    //典型小区空置户趋势
    let typicalResidential = zzkzlData.typicalResidentialVacancyTrends;
    let typicalResidentialVacancyTrends = {};
    typicalResidential.forEach( info => {
        let {month, quantity} = info;
        typicalResidentialVacancyTrends[month] = quantity;
    });

    return {typicalResidential};
}